Scarab commit: svn commit: r10251 - branches/release/b21/extensions/scripts/nightly-tarball.sh

[email protected]
Newsgroups gmane.comp.java.scarab.cvs
Message-ID <[email protected]>
Author: dabbous
Date: 2006-08-07 13:28:34-0700
New Revision: 10251

Modified:
   branches/release/b21/extensions/scripts/nightly-tarball.sh

Log:
added branch name to tag, e.g.: scarab-trunk-20060807.tgz

Modified: branches/release/b21/extensions/scripts/nightly-tarball.sh
Url: http://scarab.tigris.org/source/browse/scarab/branches/release/b21/extensions/scripts/nightly-tarball.sh?view=diff&rev=10251&p1=branches/release/b21/extensions/scripts/nightly-tarball.sh&p2=branches/release/b21/extensions/scripts/nightly-tarball.sh&r1=10250&r2=10251
==============================================================================
--- branches/release/b21/extensions/scripts/nightly-tarball.sh	(original)
+++ branches/release/b21/extensions/scripts/nightly-tarball.sh	2006-08-07 13:28:34-0700
@@ -7,11 +7,12 @@
 # Serial number
 SERIAL=`date +%Y%m%d`
 
 # CVS Module name
 MODULE=scarab
+BRANCH=trunk
 
 # Name for distribution
-TAG=${MODULE}-${SERIAL}
+TAG=${MODULE}-${BRANCH}-${SERIAL}
 
 # Path to public ftp/http directory
 PUBDIR=${HOME}/public_html/${MODULE}/nightly
@@ -7,11 +7,12 @@
 SERIAL=`date +%Y%m%d`
 
-# CVS Module name
+# svn Module name and branch
 MODULE=scarab
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.